@@ -62,8 +62,3 @@ class ConfirmRelationRequest(RpcRequest):
 	def set_PermissionCodess(self, PermissionCodes):  # RepeatList
 		for depth1 in range(len(PermissionCodes)):
 			self.add_query_param('PermissionCodes.' + str(depth1 + 1), PermissionCodes[depth1])
-	def get_RelationId(self): # Long
-		return self.get_query_params().get('RelationId')
-
-	def set_RelationId(self, RelationId):  # Long
-		self.add_query_param('RelationId', RelationId)
