@@ -23,7 +23,7 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class CreateCostUnitRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateCostUnit','bssopenapi')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateCostUnit')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
