@@ -19,12 +19,11 @@
 
 from aliyunsdkcore.request import RpcRequest
 from aliyunsdkbssopenapi.endpoint import endpoint_data
-import json
 
 class CreateSavingsPlansInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateSavingsPlansInstance','bssopenapi')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateSavingsPlansInstance')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -67,11 +66,6 @@ class CreateSavingsPlansInstanceRequest(RpcRequest):
 
 	def set_SpecType(self, SpecType):  # String
 		self.add_query_param('SpecType', SpecType)
-	def get_ExtendMap(self): # Map
-		return self.get_query_params().get('ExtendMap')
-
-	def set_ExtendMap(self, ExtendMap):  # Map
-		self.add_query_param("ExtendMap", json.dumps(ExtendMap))
 	def get_PayMode(self): # String
 		return self.get_query_params().get('PayMode')
 
