@@ -23,7 +23,7 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class DescribeSplitItemBillRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'DescribeSplitItemBill','bssopenapi')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'DescribeSplitItemBill')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,11 +36,6 @@ class DescribeSplitItemBillRequest(RpcRequest):
 
 	def set_ProductCode(self, ProductCode):  # String
 		self.add_query_param('ProductCode', ProductCode)
-	def get_IsHideZeroCharge(self): # Boolean
-		return self.get_query_params().get('IsHideZeroCharge')
-
-	def set_IsHideZeroCharge(self, IsHideZeroCharge):  # Boolean
-		self.add_query_param('IsHideZeroCharge', IsHideZeroCharge)
 	def get_SubscriptionType(self): # String
 		return self.get_query_params().get('SubscriptionType')
 
@@ -83,7 +78,7 @@ class DescribeSplitItemBillRequest(RpcRequest):
 		for depth1 in range(len(TagFilter)):
 			if TagFilter[depth1].get('TagValues') is not None:
 				for depth2 in range(len(TagFilter[depth1].get('TagValues'))):
-					self.add_query_param('TagFilter.' + str(depth1 + 1) + '.TagValues.' + str(depth2 + 1), TagFilter[depth1].get('TagValues')[depth2])
+					self.add_query_param('TagFilter.' + str(depth1 + 1) + '.TagValues' + str(depth2 + 1), TagFilter[depth1].get('TagValues')[depth2])
 			if TagFilter[depth1].get('TagKey') is not None:
 				self.add_query_param('TagFilter.' + str(depth1 + 1) + '.TagKey', TagFilter[depth1].get('TagKey'))
 	def get_BillingDate(self): # String
@@ -106,8 +101,3 @@ class DescribeSplitItemBillRequest(RpcRequest):
 
 	def set_MaxResults(self, MaxResults):  # Integer
 		self.add_query_param('MaxResults', MaxResults)
-	def get_PipCode(self): # String
-		return self.get_query_params().get('PipCode')
-
-	def set_PipCode(self, PipCode):  # String
-		self.add_query_param('PipCode', PipCode)
