@@ -23,64 +23,56 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class GetResourcePackagePriceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'GetResourcePackagePrice','bssopenapi')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'GetResourcePackagePrice')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ProductCode(self):
+	def get_ProductCode(self): # String
 		return self.get_query_params().get('ProductCode')
 
-	def set_ProductCode(self,ProductCode):
-		self.add_query_param('ProductCode',ProductCode)
-
-	def get_Specification(self):
+	def set_ProductCode(self, ProductCode):  # String
+		self.add_query_param('ProductCode', ProductCode)
+	def get_Specification(self): # String
 		return self.get_query_params().get('Specification')
 
-	def set_Specification(self,Specification):
-		self.add_query_param('Specification',Specification)
-
-	def get_OwnerId(self):
+	def set_Specification(self, Specification):  # String
+		self.add_query_param('Specification', Specification)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_EffectiveDate(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_EffectiveDate(self): # String
 		return self.get_query_params().get('EffectiveDate')
 
-	def set_EffectiveDate(self,EffectiveDate):
-		self.add_query_param('EffectiveDate',EffectiveDate)
-
-	def get_Duration(self):
+	def set_EffectiveDate(self, EffectiveDate):  # String
+		self.add_query_param('EffectiveDate', EffectiveDate)
+	def get_Duration(self): # Integer
 		return self.get_query_params().get('Duration')
 
-	def set_Duration(self,Duration):
-		self.add_query_param('Duration',Duration)
-
-	def get_InstanceId(self):
+	def set_Duration(self, Duration):  # Integer
+		self.add_query_param('Duration', Duration)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_PackageType(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_PackageType(self): # String
 		return self.get_query_params().get('PackageType')
 
-	def set_PackageType(self,PackageType):
-		self.add_query_param('PackageType',PackageType)
-
-	def get_PricingCycle(self):
+	def set_PackageType(self, PackageType):  # String
+		self.add_query_param('PackageType', PackageType)
+	def get_PricingCycle(self): # String
 		return self.get_query_params().get('PricingCycle')
 
-	def set_PricingCycle(self,PricingCycle):
-		self.add_query_param('PricingCycle',PricingCycle)
-
-	def get_OrderType(self):
+	def set_PricingCycle(self, PricingCycle):  # String
+		self.add_query_param('PricingCycle', PricingCycle)
+	def get_OrderType(self): # String
 		return self.get_query_params().get('OrderType')
 
-	def set_OrderType(self,OrderType):
-		self.add_query_param('OrderType',OrderType)
\ No newline at end of file
+	def set_OrderType(self, OrderType):  # String
+		self.add_query_param('OrderType', OrderType)
