@@ -25,80 +25,69 @@ class QueryInstanceBillRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryInstanceBill')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ProductCode(self):
+	def get_ProductCode(self): # String
 		return self.get_query_params().get('ProductCode')
 
-	def set_ProductCode(self,ProductCode):
-		self.add_query_param('ProductCode',ProductCode)
-
-	def get_IsHideZeroCharge(self):
+	def set_ProductCode(self, ProductCode):  # String
+		self.add_query_param('ProductCode', ProductCode)
+	def get_IsHideZeroCharge(self): # Boolean
 		return self.get_query_params().get('IsHideZeroCharge')
 
-	def set_IsHideZeroCharge(self,IsHideZeroCharge):
-		self.add_query_param('IsHideZeroCharge',IsHideZeroCharge)
-
-	def get_SubscriptionType(self):
+	def set_IsHideZeroCharge(self, IsHideZeroCharge):  # Boolean
+		self.add_query_param('IsHideZeroCharge', IsHideZeroCharge)
+	def get_SubscriptionType(self): # String
 		return self.get_query_params().get('SubscriptionType')
 
-	def set_SubscriptionType(self,SubscriptionType):
-		self.add_query_param('SubscriptionType',SubscriptionType)
-
-	def get_BillingCycle(self):
+	def set_SubscriptionType(self, SubscriptionType):  # String
+		self.add_query_param('SubscriptionType', SubscriptionType)
+	def get_BillingCycle(self): # String
 		return self.get_query_params().get('BillingCycle')
 
-	def set_BillingCycle(self,BillingCycle):
-		self.add_query_param('BillingCycle',BillingCycle)
-
-	def get_OwnerId(self):
+	def set_BillingCycle(self, BillingCycle):  # String
+		self.add_query_param('BillingCycle', BillingCycle)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PageNum(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
-
-	def get_BillOwnerId(self):
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_BillOwnerId(self): # Long
 		return self.get_query_params().get('BillOwnerId')
 
-	def set_BillOwnerId(self,BillOwnerId):
-		self.add_query_param('BillOwnerId',BillOwnerId)
-
-	def get_BillingDate(self):
+	def set_BillOwnerId(self, BillOwnerId):  # Long
+		self.add_query_param('BillOwnerId', BillOwnerId)
+	def get_BillingDate(self): # String
 		return self.get_query_params().get('BillingDate')
 
-	def set_BillingDate(self,BillingDate):
-		self.add_query_param('BillingDate',BillingDate)
-
-	def get_ProductType(self):
+	def set_BillingDate(self, BillingDate):  # String
+		self.add_query_param('BillingDate', BillingDate)
+	def get_ProductType(self): # String
 		return self.get_query_params().get('ProductType')
 
-	def set_ProductType(self,ProductType):
-		self.add_query_param('ProductType',ProductType)
-
-	def get_IsBillingItem(self):
+	def set_ProductType(self, ProductType):  # String
+		self.add_query_param('ProductType', ProductType)
+	def get_IsBillingItem(self): # Boolean
 		return self.get_query_params().get('IsBillingItem')
 
-	def set_IsBillingItem(self,IsBillingItem):
-		self.add_query_param('IsBillingItem',IsBillingItem)
-
-	def get_Granularity(self):
+	def set_IsBillingItem(self, IsBillingItem):  # Boolean
+		self.add_query_param('IsBillingItem', IsBillingItem)
+	def get_Granularity(self): # String
 		return self.get_query_params().get('Granularity')
 
-	def set_Granularity(self,Granularity):
-		self.add_query_param('Granularity',Granularity)
-
-	def get_PageSize(self):
+	def set_Granularity(self, Granularity):  # String
+		self.add_query_param('Granularity', Granularity)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
