@@ -23,7 +23,7 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class SubscribeBillToOSSRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'SubscribeBillToOSS','bssopenapi')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'SubscribeBillToOSS')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -46,11 +46,6 @@ class SubscribeBillToOSSRequest(RpcRequest):
 
 	def set_SubscribeBucket(self, SubscribeBucket):  # String
 		self.add_query_param('SubscribeBucket', SubscribeBucket)
-	def get_BucketPath(self): # String
-		return self.get_query_params().get('BucketPath')
-
-	def set_BucketPath(self, BucketPath):  # String
-		self.add_query_param('BucketPath', BucketPath)
 	def get_BeginBillingCycle(self): # String
 		return self.get_query_params().get('BeginBillingCycle')
 
